#
# spec file for package python-azure-multiapi-storage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-multiapi-storage
Version:        1.2.0
Release:        2.1
Summary:        MS Azure Storage Client Library for Python - with Multi API version Support
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-multiapi-storage/azure-multiapi-storage-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-common
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-cryptography >= 2.1.4
Requires:       python-msrest >= 0.6.18
Requires:       python-python-dateutil
Requires:       python-requests
Requires:       (python-azure-core >= 1.10.0 with python-azure-core < 2.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-multiapi-storage < 1.2.0
%endif
BuildArch:      noarch

%python_subpackages

%description
Microsoft Azure Storage Client Library for Python - with Multi API version Support

Handles multi-API versions of Azure Storage Data Plane originally from https://github.com/Azure/azure-storage-python.

**NOTE:**

- This is not an official Azure Storage SDK.

- It is used by https://github.com/Azure/azure-cli to support multiple API versions.

- The official Azure Storage SDK is at https://github.com/Azure/azure-storage-python.

%prep
%setup -q -n azure-multiapi-storage-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-multiapi-storage-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/azure/multiapi
%{python_sitelib}/azure_multiapi_storage-*.dist-info

%changelog
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Mon Jul  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Wed May  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue Feb 28 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Trim Summary to not exceed 79 characters
* Wed Jan  4 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Fri Sep 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.10.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue May 24 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.9.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Thu Mar 24 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.8.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Mon Nov  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.7.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Mon Mar 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.2
  + For detailed information about changes see the
    README.rst file provided with this package
- Update Requires from setup.py
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Thu Nov 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.5.2
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue Sep  1 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.4.1
  + For detailed information about changes see the
    README.rst file provided with this package
* Thu May  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.3.2
  + For detailed information about changes see the
    README.rst file provided with this package
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.2.4
  + For detailed information about changes see the
    README.rst file provided with this package
- Drop patch to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + ams_drop-extras-require.patch
* Mon Apr 15 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.2.3
  + For detailed information about changes see the
    README.rst file provided with this package
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Thu Sep  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.2.2
  + For detailed information about changes see the
    README.rst file provided with this package
- Add patch to remove extras_require field from setup.py, required
  for SLES12 as the setuptools version is too old
  + ams_drop-extras-require.patch
- Move LICENSE.txt from %%doc to %%license section
* Mon Apr 23 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.2.0
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue Jan 30 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.1.7
  + For detailed information about changes see the
    README.rst file provided with this package
* Wed Sep 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.1.4
